@@ -1,11 +1,7 @@
 from __future__ import unicode_literals
-import time
 from decimal import Decimal
 from unittest import TestCase
 
-from django.http import HttpResponse, HttpResponseForbidden
-from mock import MagicMock
-
 from . import StripeProvider
 
 
